@@ -32,7 +32,7 @@ from copy import copy, deepcopy
 from typing import Union, Optional  # noqa F401
 
 import numpy as np
-from osgeo import gdal, gdal_array, gdalnumeric
+from osgeo import gdal, gdal_array
 from shapely.geometry import Polygon
 from shapely.wkt import loads as shply_loads
 # dill -> imported when dumping GeoArray
@@ -50,7 +50,7 @@ from py_tools_ds.io.raster.gdal import get_GDAL_ds_inmem
 from py_tools_ds.numeric.numbers import is_number
 from py_tools_ds.numeric.array import get_array_tilebounds
 
-#  internal imports
+# internal imports
 from .subsetting import get_array_at_mapPos
 from .metadata import GDAL_Metadata
 
@@ -495,7 +495,7 @@ class GeoArray(object):
             else:
                 try:
                     multipolygon = raster2polygon(self.mask_nodata.astype(np.uint8), self.gt, self.prj, exact=False,
-                                                  progress=self.progress, q=self.q, maxfeatCount=10, timeout=15)
+                                                  min_npx=10, progress=self.progress, q=self.q, timeout=15)
                     self._footprint_poly = fill_holes_within_poly(multipolygon)
                 except (RuntimeError, TimeoutError):
                     if not self.q:
@@ -956,7 +956,7 @@ class GeoArray(object):
             # TODO insert a multiprocessing.Lock here in order to prevent IO bottlenecks?
             # read subset area from disk
             if bL == list(range(0, B)):
-                tempArr = gdalnumeric.LoadFile(path, cS, rS, cE - cS + 1, rE - rS + 1)
+                tempArr = gdal_array.LoadFile(path, cS, rS, cE - cS + 1, rE - rS + 1)
                 out_arr = np.swapaxes(np.swapaxes(tempArr, 0, 2), 0, 1) if B > 1 else tempArr
                 if out_arr is None:
                     raise Exception('Error reading file:  ' + gdal.GetLastErrorMsg())
@@ -1938,7 +1938,7 @@ class GeoArray(object):
 
 def get_GeoArray_from_GDAL_ds(ds):
     # TODO implement as class method of GeoArray
-    arr = gdalnumeric.DatasetReadAsArray(ds)
+    arr = gdal_array.DatasetReadAsArray(ds)
     if len(arr.shape) == 3:
         arr = np.swapaxes(np.swapaxes(arr, 0, 2), 0, 1)
     return GeoArray(arr, ds.GetGeoTransform(), ds.GetProjection())
